import request from '@/utils/request'

export function dmZgHaveDinner(params) {
  return request({
    url: 'api/dmHaveDinner/dmZgHaveDinner',
    method: 'get',
    params
  })
}

export function dmZdHaveDinner(params) {
  return request({
    url: 'api/dmHaveDinner/dmZdHaveDinner',
    method: 'get',
    params
  })
}

export function downloadTop(data) {
  return request({
    url: 'api/dmHaveDinner/downloadTop',
    method: 'get',
    responseType: 'blob',
    data
  })
}

export function downloadStop(data) {
  return request({
    url: 'api/dmHaveDinner/downloadStop',
    method: 'get',
    responseType: 'blob',
    data
  })
}
export default {
  dmZgHaveDinner,
  dmZdHaveDinner,
  downloadTop,
  downloadStop
}
